summaryrefslogtreecommitdiff
path: root/libs/ardour/session.cc
diff options
context:
space:
mode:
authorPaul Davis <paul@linuxaudiosystems.com>2017-06-23 16:34:12 -0400
committerPaul Davis <paul@linuxaudiosystems.com>2017-09-18 11:40:53 -0400
commitc6bd03352382094b9d8996c16c1a681c2cb495c3 (patch)
tree6a069c0baa1e2204b0778650a561c188229f612c /libs/ardour/session.cc
parent79abf3dfa6d649fbf1fb6fd16cd489f434d0b909 (diff)
update disk writer input latency at transport stop
Diffstat (limited to 'libs/ardour/session.cc')
-rw-r--r--libs/ardour/session.cc10
1 files changed, 5 insertions, 5 deletions
diff --git a/libs/ardour/session.cc b/libs/ardour/session.cc
index 87adc25275..01c8bfa62f 100644
--- a/libs/ardour/session.cc
+++ b/libs/ardour/session.cc
@@ -5737,7 +5737,7 @@ Session::graph_reordered ()
for (RouteList::iterator i = rl->begin(); i != rl->end(); ++i) {
boost::shared_ptr<Track> tr = boost::dynamic_pointer_cast<Track> (*i);
if (tr) {
- tr->set_capture_offset ();
+ tr->update_latency_information ();
}
}
}
@@ -6936,7 +6936,7 @@ Session::post_capture_latency ()
for (RouteList::iterator i = rl->begin(); i != rl->end(); ++i) {
boost::shared_ptr<Track> tr = boost::dynamic_pointer_cast<Track> (*i);
if (tr) {
- tr->set_capture_offset ();
+ tr->update_latency_information ();
}
}
}
@@ -7045,7 +7045,7 @@ Session::update_latency_compensation (bool force_whole_graph)
if (!tr) {
continue;
}
- tr->set_capture_offset ();
+ tr->update_latency_information ();
}
}
@@ -7378,8 +7378,8 @@ Session::auto_connect_thread_run ()
/* this is only used for updating plugin latencies, the
* graph does not change. so it's safe in general.
* BUT..
* .. update_latency_compensation () entails set_capture_offset()
* which calls Diskstream::set_capture_offset () which
* modifies the capture offset... which can be a proplem
* in "prepare_to_stop"
*/
@@ -7378,8 +7378,8 @@ Session::auto_connect_thread_run ()
* graph does not change. so it's safe in general.
* BUT..
- * .. update_latency_compensation () entails set_capture_offset()
- * which calls Diskstream::set_capture_offset () which
+ * .. update_latency_compensation () entails Track::update_latency_information()
+ * which calls DiskWriter::set_capture_offset () which
* modifies the capture offset... which can be a proplem
* in "prepare_to_stop"